phoneapp/phoneuistates/src/cphoneconferenceandwaiting.cpp
branchRCL_3
changeset 14 24062c24fe38
parent 9 8871b09be73b
child 15 2a26698d78ba
--- a/phoneapp/phoneuistates/src/cphoneconferenceandwaiting.cpp	Fri Feb 19 22:50:26 2010 +0200
+++ b/phoneapp/phoneuistates/src/cphoneconferenceandwaiting.cpp	Fri Mar 12 15:42:40 2010 +0200
@@ -228,6 +228,13 @@
         resourceId = EPhoneConfCallParticipantsMenubar;    
         }        
     
+    TPhoneCmdParamBoolean booleanParam;
+    const TBool videoWaiting = IsVideoCallRingingL();
+    booleanParam.SetBoolean( videoWaiting );
+    iViewCommandHandle->ExecuteCommandL( EPhoneViewSetConferenceAndWaitingVideo,
+        &booleanParam );
+    
+    
     TPhoneCmdParamInteger integerParam;
     integerParam.SetInteger( 
                 CPhoneMainResourceResolver::Instance()->
@@ -290,7 +297,7 @@
     
     // Effect is shown when dialer exist.
     TBool effectStarted ( EFalse );
-    if ( !NeedToSendToBackgroundL() )
+    if ( !NeedToReturnToForegroundAppL() )
         {
         BeginTransEffectLC( ENumberEntryOpen );
         effectStarted = ETrue; 
@@ -314,31 +321,16 @@
     
     if ( IsNumberEntryUsedL() )
         {
-        if ( NeedToSendToBackgroundL() )
+        if ( NeedToReturnToForegroundAppL() )
             {
-            // Return phone to the background if send to background is needed.
-            iViewCommandHandle->ExecuteCommandL( EPhoneViewSendToBackground );
-            
             iViewCommandHandle->ExecuteCommandL( EPhoneViewSetControlAndVisibility );
             
             UpdateCbaL( EPhoneCallHandlingInCallCBA );
             }
-        else
-            {
-            // Show the number entry if it exists.
-            SetNumberEntryVisibilityL(ETrue);
-            }
         }
     else
         {
         UpdateCbaL( EPhoneCallHandlingNewCallSwapCBA );
-        // If numberentry is not open just check NeedToSendToBackgroundL and 
-        // sendbackround if needed.
-        if ( NeedToSendToBackgroundL() )
-            {
-            // Return phone to the background if send to background is needed.
-            iViewCommandHandle->ExecuteCommandL( EPhoneViewSendToBackground );
-            }
         }
     SetTouchPaneButtons( EPhoneConferenceAndSingleButtons );
     SetTouchPaneButtonDisabled( EPhoneInCallCmdPrivate );
@@ -374,7 +366,7 @@
         {
         // Effect is shown when dialer exist.
         TBool effectStarted ( EFalse );
-        if ( !NeedToSendToBackgroundL() )
+        if ( !NeedToReturnToForegroundAppL() )
             {
             BeginTransEffectLC( ENumberEntryOpen );
             effectStarted = ETrue;
@@ -391,27 +383,22 @@
             
         if ( IsNumberEntryUsedL() )
             {
-            if ( NeedToSendToBackgroundL() )
+            if ( NeedToReturnToForegroundAppL() ) 
                 {
                 // Return phone to the background if send to background is needed.
                 iViewCommandHandle->ExecuteCommandL( EPhoneViewSendToBackground );
  
                 iViewCommandHandle->ExecuteCommandL( EPhoneViewSetControlAndVisibility );
                 
                 UpdateCbaL( EPhoneCallHandlingInCallCBA );
                 }
-            else
-                {
-                // Show the number entry if it exists.
-                SetNumberEntryVisibilityL(ETrue);
-                }
             }
         else
             {
             UpdateCbaL( EPhoneCallHandlingInCallCBA );
             // If numberentry is not open just check NeedToSendToBackgroundL and 
             // sendbackround if needed.
-            if ( NeedToSendToBackgroundL() )
+            if ( NeedToReturnToForegroundAppL() )
                 {
                 // Return phone to the background if send to background is needed.
                 iViewCommandHandle->ExecuteCommandL( EPhoneViewSendToBackground );
@@ -391,27 +383,22 @@
                 {
-                // Return phone to the background if send to background is needed.
+                // Return phone to the background if menu application is needed to foreground.
                 iViewCommandHandle->ExecuteCommandL( EPhoneViewSendToBackground );
  
@@ -391,27 +383,22 @@
             {
             UpdateCbaL( EPhoneCallHandlingInCallCBA );
-            // If numberentry is not open just check NeedToSendToBackgroundL and 
+            // If numberentry is not open just check NeedToReturnToForegroundAppL and 
             // sendbackround if needed.